import { By } from '@angular/platform-browser';
import { SkyAppTestUtility } from '@skyux-sdk/testing';
import { SkyComponentHarness, SkyHarnessUtility } from '@skyux/core/testing';
import { SkyErrorModalHarness } from '@skyux/errors/testing';
import { SkyFileDropHarness } from '@skyux/forms/testing';

/**
 * Allows interaction with a SKY UX avatar component.
 * @deprecated Use `SkyAvatarHarness` instead.
 * @internal
 */
class SkyAvatarFixture {
    /**
     * The initials displayed when no image URL is specified.
     */
    get initials() {
        const initialsEl = this.#debugEl.query(By.css('.sky-avatar-initials'));
        if (SkyAppTestUtility.isVisible(initialsEl)) {
            return SkyAppTestUtility.getText(initialsEl.query(By.css('.sky-avatar-initials-inner')));
        }
        return undefined;
    }
    /**
     * The avatar's current image URL.
     */
    get imageUrl() {
        const imageEl = this.#debugEl.query(By.css('.sky-avatar-image'));
        if (SkyAppTestUtility.isVisible(imageEl)) {
            return SkyAppTestUtility.getBackgroundImageUrl(imageEl);
        }
        return undefined;
    }
    #debugEl;
    constructor(fixture, skyTestId) {
        this.#debugEl = SkyAppTestUtility.getDebugElementByTestId(fixture, skyTestId, 'sky-avatar');
    }
}

const WAIT_INTERVAL = 10;
const WAIT_TIMEOUT = 3000;
async function isHidden(el) {
    return (await el.getCssValue('display')) === 'none';
}
/**
 * Harness for interacting with an avatar component in tests.
 */
class SkyAvatarHarness extends SkyComponentHarness {
    /**
     * @internal
     */
    static { this.hostSelector = 'sky-avatar'; }
    #documentRootLocator = this.documentRootLocatorFactory();
    #getFileDrop = this.locatorForOptional(SkyFileDropHarness);
    #errorModal = this.#documentRootLocator.locatorForOptional(SkyErrorModalHarness);
    /**
     * Gets a `HarnessPredicate` that can be used to search for a
     * `SkyAvatarHarness` that meets certain criteria.
     */
    static with(filters) {
        return SkyAvatarHarness.getDataSkyIdPredicate(filters);
    }
    /**
     * Gets the initials displayed when no image URL is specified.
     */
    async getInitials() {
        const initialsEl = await this.locatorFor('.sky-avatar-initials')();
        if (await isHidden(initialsEl)) {
            return undefined;
        }
        return await initialsEl.text();
    }
    /**
     * Gets the avatar's current image URL or Blob.
     */
    async getSrc() {
        const url = await this.#getImageUrl();
        if (url?.startsWith('blob:')) {
            return await (await fetch(url)).blob();
        }
        return url;
    }
    /**
     * Gets whether users can change the image.
     */
    async getCanChange() {
        return !!(await this.#getFileDrop());
    }
    /**
     * Simulates the user selecting or dropping an image onto the component.
     */
    async dropAvatarFile(file, waitForChange) {
        const fileDrop = await this.#getFileDrop();
        if (!fileDrop) {
            throw new Error('A new avatar cannot be selected because the canChange input is not set to true.');
        }
        if (waitForChange) {
            await this.#dropAndWait(fileDrop, file);
        }
        else {
            await fileDrop.loadFile(file);
        }
    }
    /**
     * Gets whether an error indicating an invalid file type is displayed.
     */
    async hasFileTypeError() {
        const errorModal = await this.#errorModal();
        return !!(await errorModal?.getTitle())?.includes('File is not an image.');
    }
    /**
     * Gets whether an error indicating an invalid file size is displayed.
     */
    async hasMaxSizeError() {
        const errorModal = await this.#errorModal();
        return !!(await errorModal?.getTitle())?.includes('File is too large.');
    }
    /**
     * Closes the currently displayed error.
     */
    async closeError() {
        const errorModal = await this.#errorModal();
        if (!errorModal) {
            throw new Error('No error is currently displayed.');
        }
        await errorModal.clickCloseButton();
    }
    async #getImageUrl() {
        const imageEl = await this.locatorFor('.sky-avatar-image')();
        if (await isHidden(imageEl)) {
            return undefined;
        }
        return await SkyHarnessUtility.getBackgroundImageUrl(imageEl);
    }
    async #dropAndWait(fileDrop, file) {
        const currentUrl = await this.#getImageUrl();
        await fileDrop.loadFile(file);
        return await new Promise((resolve, reject) => {
            const checkForFileChange = async (attempts) => {
                if ((await this.#getImageUrl()) !== currentUrl) {
                    resolve();
                }
                else if (attempts * WAIT_INTERVAL < WAIT_TIMEOUT) {
                    setTimeout(() => void checkForFileChange(attempts + 1), WAIT_INTERVAL);
                }
                else {
                    reject(new Error('The avatar src did not change within the expected time span'));
                }
            };
            void checkForFileChange(0);
        });
    }
}

/**
 * Generated bundle index. Do not edit.
 */

export { SkyAvatarFixture, SkyAvatarHarness };
//# sourceMappingURL=skyux-avatar-testing.mjs.map
